import http from '@/api/http';
// 获取微信小程序充值会员信息
export function wechatMinUserInfo(id: number | string) {
  return http.get(`/channel/wechat_min_user/detail/${id}`);
}

/**
 * 获取微信小程序充值会员充值记录
 */
export function channelWechatMinUserOrderList(params: object) {
  return http.get('/channel/wechat_min_user/order_list', params);
}
/**
 * 获取微信小程序充会员的消费记录
 */
export function channelWechatMinUserConsumeRecord(params: object) {
  return http.get('/channel/wechat_min_user/consume_record', params);
}
/**
 * 获取微信小程序充值会员观看记录
 */
export function channelWechatMinUserWatchRecord(params: object) {
  return http.get('/channel/wechat_min_user/watch_record', params);
}

/**
 * 订单列表
 */
export function channelOrderList(params: object) {
  return http.get('/channel/order_list', params);
}
/**
 * 订单列表小程序选择项
 */
export function channelMiniprogramUseList(params: object) {
  return http.get('/channel/miniprogram/use_list', params);
}
/**
 * 订单列表推广选择项
 */
export function channelPromotionsOptions(params: object) {
  return http.get('/channel/promotions/options', params);
}
/**
 * 订单列表优化师选项
 */
export function channelPromotionsUsers(params: object) {
  return http.get('/channel/promotions/users', params);
}
/**
 * 支付状态选择项
 */
export function channelOrderStatus(params?: object) {
  return http.get('/channel/order_status', params);
}
/**
 * 充值类型选择项
 */
export function channelOrderType(params?: object) {
  return http.get('/channel/order_types', params);
}
/**
 * 退款订单列表
 */
export function orderRefundOrderList(params: object) {
  return http.get('/orderRefund/order_list', params);
}

/**
 * 退款申请
 */
export function orderRefundApply(params: object) {
  return http.post(`/orderRefund/apply`, params);
}
/**
 * 平台审核
 */
export function orderRefundVerifyPt(params: object) {
  return http.post(`/orderRefund/verify/pt`, params);
}
/**
 * 商户审核
 */
export function orderRefundVerifySh(params: object) {
  return http.post(`/orderRefund/verify/sh`, params);
}
/**
 * 退款操作
 */
export function orderRefundPayToUser(params: object) {
  return http.post(`/orderRefund/payToUser`, params);
}
